@@ -350,7 +350,7 @@ class acidoBasicMainWindow(QMainWindow):
                          yRightTitre="pH")
         self.replot()
 
-    def setGrid(self, qwtp, titre=QApplication.translate("pyacidobasic", "Courbe du dosage", None, QApplication.UnicodeUTF8),
+    def setGrid(self, qwtp, titre="",
                 yLeftRange=(0,14),
                 yRightRange=None,
                 xTitre="V (mL)",
@@ -367,6 +367,8 @@ class acidoBasicMainWindow(QMainWindow):
         @param yLeftTitre le label de l'axe Y de gauche, "pH" par défaut
         @param yRightTitre le label de l'axe Y de droite, "Concentration (mol/L)" par défaut
         """
+        if titre=="":
+            titre=QApplication.translate("pyacidobasic", "Courbe du dosage", None, QApplication.UnicodeUTF8)
         qwtp.setAxisScale(QwtPlot.yLeft,yLeftRange[0],yLeftRange[1])
         qwtp.setAxisTitle(QwtPlot.xBottom,xTitre)
         qwtp.setAxisTitle(QwtPlot.yLeft,yLeftTitre)
