@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="fr_FR">
+<!DOCTYPE TS><TS version="2.0" language="en_US" sourcelanguage="fr_FR">
 <context>
     <name>Dialog</name>
     <message>
@@ -91,7 +91,7 @@
     <message>
         <location filename="../main.ui" line="596"/>
         <source>exporter au format JPEG</source>
-        <translation>export in JPGE format</translation>
+        <translation>export in JPEG format</translation>
     </message>
     <message>
         <location filename="../main.ui" line="613"/>
@@ -111,7 +111,7 @@
     <message>
         <location filename="../main.ui" line="498"/>
         <source>Concentrations</source>
-        <translation type="unfinished">Concentrations</translation>
+        <translation>Concentrations</translation>
     </message>
     <message>
         <location filename="../main.ui" line="697"/>
@@ -241,32 +241,32 @@
     <message encoding="UTF-8">
         <location filename="../main.ui" line="122"/>
         <source>Filtre :</source>
-        <translation type="unfinished"></translation>
+        <translation>Filter:</translation>
     </message>
     <message encoding="UTF-8">
         <location filename="../main.ui" line="110"/>
         <source>Taper quelques lettres du réactif pour le sélectionner plus facilement</source>
-        <translation type="unfinished"></translation>
+        <translation>Type in a few charcters of the reagent</translation>
     </message>
     <message>
         <location filename="../main.ui" line="135"/>
         <source>Cliquer pour effacer le filtre</source>
-        <translation type="unfinished"></translation>
+        <translation>Click to delete the filter</translation>
     </message>
     <message encoding="UTF-8">
         <location filename="../main.ui" line="451"/>
         <source>Concentrations/Quantités</source>
-        <translation type="unfinished"></translation>
+        <translation>Concentrations/Quantities</translation>
     </message>
     <message encoding="UTF-8">
         <location filename="../main.ui" line="508"/>
         <source>Quantités</source>
-        <translation type="unfinished"></translation>
+        <translation>Quantities</translation>
     </message>
     <message encoding="UTF-8">
         <location filename="../main.ui" line="486"/>
         <source>Choisir le type de représentation</source>
-        <translation type="unfinished"></translation>
+        <translation>Choose the type of plot</translation>
     </message>
 </context>
 <context>
@@ -287,7 +287,7 @@
         <translation>Version error</translation>
     </message>
     <message>
-        <location filename="../__init__.py" line="353"/>
+        <location filename="../__init__.py" line="371"/>
         <source>Courbe du dosage</source>
         <translation>Titration plot</translation>
     </message>
